﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Data;
using System.IO;

namespace SampleProject_BromcomAPIs
{
    class Program
    {
        static void Main(string[] args)
        {
            string formatType = String.Empty;
            int schoolId = -1;
            string username = String.Empty;
            string password = String.Empty;
            string entityName = String.Empty;
            string entityFilter = String.Empty;

            //FileFormatType
            if (args != null && args.Length > 0)
                formatType = args[0].ToUpper();

            //SchoolID
            if (args != null && args.Length > 1)
                Int32.TryParse(args[1], out schoolId);                

            //Username
            if (args != null && args.Length > 2)
                username = args[2];

            //Password
            if (args != null && args.Length > 3)
                password = args[3];

            //EntityName
            if (args != null && args.Length > 4)
                entityName = args[4];

            //EntityFilter
            if (args != null && args.Length > 5)
                entityFilter = args[5];

            if(formatType == String.Empty || schoolId == -1 || username == String.Empty || password == String.Empty)
                throw new Exception("Invalid Parameters: [(R)FormatType] [(R)SchoolID] [(R)Username] [(R)Password] [(O)EntityName] [(O)EntityFilter]");

            if (formatType != "TAB" && formatType != "COMMA" && formatType != "XML")
                throw new Exception("Invalid Format Type - Supported Format Types: TAB/COMMA/XML");

            DataSet resultDataSet;
            if (entityName == String.Empty && entityFilter == String.Empty)
            {
                //Get Entities
                TPReadOnlyDataService.TPReadOnlyDataServiceSoapClient readOnlyServiceClient = new TPReadOnlyDataService.TPReadOnlyDataServiceSoapClient();
                resultDataSet = readOnlyServiceClient.findEntitiesBySchoolID(schoolId, username, password);
            }
            else
            {
                //Get Entity Data
                TPReadOnlyDataService.TPReadOnlyDataServiceSoapClient readOnlyServiceClient = new TPReadOnlyDataService.TPReadOnlyDataServiceSoapClient();
                resultDataSet = readOnlyServiceClient.getEntityDataBySchoolID(schoolId, entityName, entityFilter, username, password);
            }

            if (entityName == String.Empty)
                entityName = "Entities";

            resultDataSet.DataSetName = entityName;
            resultDataSet.Tables[0].TableName = entityName + "Row";

            if (formatType == "XML")
            {
                string fileName = entityName + ".XML";
                resultDataSet.WriteXml(fileName);
            }
            else
            {
                string fileName = entityName + ".TXT";
                string deliminator = String.Empty;

                if (formatType == "TAB")
                    deliminator = "\t";
                else if (formatType == "COMMA")
                    deliminator = ",";
                else
                    throw new Exception("");

                StringBuilder str = new StringBuilder();
                DataTable tempDataTable = resultDataSet.Tables[0];
                // get the column headers
                foreach (DataColumn c in tempDataTable.Columns)
                {
                    str.Append("\"" + c.ColumnName.ToString() + "\"" + deliminator);
                }
                str.Append("\r\n");

                // write the data here
                foreach (DataRow dr in tempDataTable.Rows)
                {
                    foreach (var field in dr.ItemArray)
                    {
                        str.Append("\"" + field.ToString() + "\"" + deliminator);
                    }
                    str.Append("\r\n");
                }

                FileStream file = new FileStream(fileName, FileMode.Create);
                StreamWriter writer = new StreamWriter(file);
                writer.Write(str.ToString());
                writer.Flush();
                writer.Close();
            }
        }
    }
}
